#ifndef _EFL_CANVAS_SURFACE_X11_EO_LEGACY_H_
#define _EFL_CANVAS_SURFACE_X11_EO_LEGACY_H_

#ifndef _EFL_CANVAS_SURFACE_X11_EO_CLASS_TYPE
#define _EFL_CANVAS_SURFACE_X11_EO_CLASS_TYPE

typedef Eo Efl_Canvas_Surface_X11;

#endif

#ifndef _EFL_CANVAS_SURFACE_X11_EO_TYPES
#define _EFL_CANVAS_SURFACE_X11_EO_TYPES

#ifdef EFL_BETA_API_SUPPORT
/** The type used by @ref efl_canvas_surface_native_buffer_get.
 *
 * @ingroup Efl_Canvas
 */
typedef struct _Efl_Canvas_Surface_X11_Pixmap
{
  void *visual; /**< X11 Visual for this Pixmap. */
  unsigned long pixmap; /**< X11 Pixmap ID. */
} Efl_Canvas_Surface_X11_Pixmap;
#endif /* EFL_BETA_API_SUPPORT */


#endif

#endif
